@@ -1,16 +1,27 @@
 from dataclasses import dataclass
-from etsy_apiv3.models.ListingProperty import ListingProperty
-from etsy_apiv3.utils.APIV3 import EtsyAuth
-from etsy_apiv3.utils.Response import Response
-from etsy_apiv3.models.Listing import Listing
+import json
+from typing import List, Optional
+from models.ListingPropertyModel import ListingProperty
+from utils.APIV3 import EtsyAuth
+from utils.Response import Response
+from models.ListingModel import Listing, Inventory
 
 @dataclass
 class ListingResource:
     
     auth: EtsyAuth
     
-    def find_one(self, listing_id, includes=""):
-        
+    def get_listing(self, listing_id: int, includes: str = "") -> Listing:
+        """
+        Retrieves a listing record by listing ID.
+
+        Args:
+            listing_id (int): Listing Id
+            includes (str, optional): An enumerated string that attaches a valid association. Acceptable inputs are 'Shipping', 'Shop', 'Images', 'User', 'Translations' and 'Inventory'. Defaults to "".
+
+        Returns:
+            Listing: A Single Listing Object
+        """
         endpoint = f"listings/{listing_id}"
         json = self.auth.request(endpoint, params={"includes":includes})
         return Listing(**json)
@@ -75,4 +86,27 @@ class ListingResource:
         response = self.auth.request(endpoint)
         return ListingProperty(**response)
     
-    
\ No newline at end of file
+    def get_listing_inventory(self, listing_id: int):
+        endpoint = f"listings/{listing_id}/inventory"
+        response = self.auth.request(endpoint)
+        return Inventory(**response)
+    
+    def update_listing_inventory(self, listing_id: int, products: List[dict], price_on_property: Optional[List[int]] = None, quantity_on_property: Optional[List[int]] = None, sku_on_property: Optional[List[int]] = None):
+        
+        data = {
+            "products":products
+        }
+
+        if price_on_property is not None:
+            data["price_on_property"] = price_on_property
+        
+        if quantity_on_property is not None:
+            data["quantity_on_property"] = quantity_on_property
+        
+        if sku_on_property is not None:
+            data["sku_on_property"] = sku_on_property
+            
+        endpoint = f"listings/{listing_id}/inventory"
+
+        response = self.auth.request(endpoint, "PUT", data=json.dumps(data))
+        return Inventory(**response)
\ No newline at end of file
