@@ -1,7 +1,7 @@
 from dataclasses import dataclass
-from etsy_apiv3.utils.APIV3 import EtsyAuth
-from etsy_apiv3.utils.Response import Response
-from etsy_apiv3.models.Review import Review
+from utils.APIV3 import EtsyAuth
+from utils.Response import Response
+from models.ReviewModel import Review
 
 @dataclass
 class ReviewResource:
